From 19eef8916cc556dffa3f9d48498bea869ee74b88 Mon Sep 17 00:00:00 2001
From: Michael Merickel <michael@merickel.org>
Date: Wed, 10 Oct 2018 09:09:49 +0200
Subject: [PATCH] use webob's new offer normalization

---
 pyramid/config/views.py |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/pyramid/config/views.py b/pyramid/config/views.py
index 8d542a8..e6baa7c 100644
--- a/pyramid/config/views.py
+++ b/pyramid/config/views.py
@@ -840,8 +840,8 @@
                     DeprecationWarning,
                     stacklevel=4,
                     )
-            # XXX when media ranges are gone, switch verify=True
-            accept = normalize_accept_offer(accept, verify=False)
+            # XXX when media ranges are gone, switch allow_range=False
+            accept = normalize_accept_offer(accept, allow_range=True)
 
         view = self.maybe_dotted(view)
         context = self.maybe_dotted(context)
@@ -1308,12 +1308,12 @@
                     'cannot compare params across different media types')
 
         def normalize_types(thans):
-            thans = [normalize_accept_offer(o, verify=False) for o in thans]
-            for o in thans:
-                check_type(o)
+            thans = [normalize_accept_offer(than) for than in thans]
+            for than in thans:
+                check_type(than)
             return thans
 
-        value = normalize_accept_offer(value, verify=False)
+        value = normalize_accept_offer(value)
         offer_type, offer_subtype, offer_params = Accept.parse_offer(value)
 
         if weighs_more_than:

--
Gitblit v1.9.3